<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://promolayer.io
 * @since      1.0.0
 *
 * @package    Promolayer
 * @subpackage Promolayer/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Promolayer
 * @subpackage Promolayer/public
 * @author     Peakdigital <hello@peakdigital.co.jp>
 */
class Promolayer_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}


	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

        $compatMode = false;
        if(in_array('wp-rocket/wp-rocket.php', apply_filters('active_plugins', get_option('active_plugins')))){
            $compatMode = true;
        }

        $promolayer = Promolayer::getInstance();
        $user_id = $promolayer->get_option('user_id');
        $pluginName = $this->plugin_name;

        $promolayerCompatLoaderScript = '(function(){if(!/Trident.*rv[ :]*(\d+\.\d+)/.test(navigator.userAgent)){var e=document.createElement("script");e.type="module",e.src="https://modules.promolayer.io/index.js",e.dataset.pluid="'.$user_id.'",e.async=!0,document.head.appendChild(e)}})();';

        if(!$compatMode) {
            wp_enqueue_script($pluginName, PROMOLAYER_SCRIPT_URL, null, null, false);
            add_filter('script_loader_tag', function ($tag, $handle, $src) use ($user_id, $pluginName) {
                if ($pluginName !== $handle) {
                    return $tag;
                };
                $tag = '<script type="module" src="' . esc_url($src) . '" data-pluid="' . $user_id . '" crossorigin async></script>';
                return $tag;
            }, 100, 3);
        } else {
            wp_register_script( 'promolayer-compat-loader', '' );
            wp_enqueue_script( 'promolayer-compat-loader' );
            wp_add_inline_script( 'promolayer-compat-loader', $promolayerCompatLoaderScript );
        }

	}

}
